@@ -29,14 +29,15 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "dialogs/dialog_color.h"
 #include "widgets/widget_color.h"
-#include <synfig/general.h>
 #include <synfigapp/main.h>
 #include <gtkmm/button.h>
 #include "app.h"
 
-#include "general.h"
+#include <gui/localization.h>
 
 #endif
 
@@ -60,6 +61,7 @@ Dialog_Color::Dialog_Color():
 	dialog_settings(this, "color"),
 	busy_(false)
 {
+	set_transient_for((Gtk::Window&)(*App::main_window));
 	set_type_hint(Gdk::WINDOW_TYPE_HINT_UTILITY);
 
 	create_color_edit_widget();
@@ -69,7 +71,6 @@ Dialog_Color::Dialog_Color():
 			sigc::mem_fun(*this, &Dialog_Color::on_set_fc_pressed));
 	create_close_button();
 
-	add_accel_group(App::ui_manager()->get_accel_group());
 	show_all_children();
 }
 
