@@ -73,22 +73,22 @@ using namespace studio;
 Dialog_Setup::Dialog_Setup(Gtk::Window& parent):
 	Dialog_Template(parent,_("Synfig Studio Preferences")),
 	input_settings(synfigapp::Main::get_selected_input_device()->settings()),
-	listviewtext_brushes_path(manage (new Gtk::ListViewText(1, true, Gtk::SELECTION_BROWSE))),
-	adj_gamma_r(Gtk::Adjustment::create(2.2,0.1,3.0,0.025,0.025,0.025)),
-	adj_gamma_g(Gtk::Adjustment::create(2.2,0.1,3.0,0.025,0.025,0.025)),
-	adj_gamma_b(Gtk::Adjustment::create(2.2,0.1,3.0,0.025,0.025,0.025)),
 	adj_recent_files(Gtk::Adjustment::create(15,1,50,1,1,0)),
 	adj_undo_depth(Gtk::Adjustment::create(100,10,5000,1,1,1)),
+	time_format(Time::FORMAT_NORMAL),
+	listviewtext_brushes_path(manage (new Gtk::ListViewText(1, true, Gtk::SELECTION_BROWSE))),
 	adj_pref_x_size(Gtk::Adjustment::create(480,1,10000,1,10,0)),
 	adj_pref_y_size(Gtk::Adjustment::create(270,1,10000,1,10,0)),
-	adj_pref_fps(Gtk::Adjustment::create(24.0,1.0,100,0.1,1,0))
+	adj_pref_fps(Gtk::Adjustment::create(24.0,1.0,100,0.1,1,0)),
+	pref_modification_flag(false),
+	refreshing(false)
 {
-	synfig::String interface_str(_("Interface")),
-			document_str(_("Document")),
-			editing_str(_("Editing")),
-			render_str(_("Render")),
-			system_str(_("System")),
-			gamma_str(_("Gamma"));
+	synfig::String
+		interface_str(_("Interface")),
+		document_str(_("Document")),
+		editing_str(_("Editing")),
+		render_str(_("Render")),
+		system_str(_("System"));
 	// WARNING FIXED ORDER : the page added to notebook same has treeview
 	// Interface
 	create_interface_page(add_page(interface_str));
@@ -99,10 +99,7 @@ Dialog_Setup::Dialog_Setup(Gtk::Window& parent):
 	// Render
 	create_render_page(add_page(render_str));
 	// System
-	PageInfo pi = add_page(system_str);
-	create_system_page(pi);
-	// Gamma
-	create_gamma_page(add_child_page(gamma_str, pi.row));
+	create_system_page(add_page(system_str));
 
 	show_all_children();
 }
@@ -111,57 +108,6 @@ Dialog_Setup::~Dialog_Setup()
 {
 }
 
-void
-Dialog_Setup::create_gamma_page(PageInfo pi)
-{
-	/*---------Gamma------------------*\
-	 *
-	 *        *****°°°°°°°#####
-	 *        *****°°°°°°°#####
-	 *        *****°°°°°°°#####
-	 *        *****°°°°°°°#####
-	 *        *****°°°°°°°#####
-	 *   red ---------x--------------
-	 * green ---------x--------------
-	 *  blue ---------x--------------
-	 * black ---------x--------------
-	 *
-	 */
-
-	int row(1);
-#ifndef __APPLE__
-	pi.grid->attach(gamma_pattern, 0, row, 2, 1);
-	gamma_pattern.set_halign(Gtk::ALIGN_CENTER);
-#endif
-	Gtk::Scale* scale_gamma_r(manage(new Gtk::Scale(adj_gamma_r)));
-	attach_label(pi.grid, _("Red"), ++row);
-	pi.grid->attach(*scale_gamma_r, 1, row, 1, 1);
-	scale_gamma_r->set_hexpand_set(true);
-	adj_gamma_r->signal_value_changed().connect(sigc::mem_fun(*this,&studio::Dialog_Setup::on_gamma_r_change));
-
-	Gtk::Scale* scale_gamma_g(manage(new Gtk::Scale(adj_gamma_g)));
-	attach_label(pi.grid, _("Green"), ++row);
-	pi.grid->attach(*scale_gamma_g, 1, row, 1, 1);
-	scale_gamma_g->set_hexpand(true);
-	adj_gamma_g->signal_value_changed().connect(sigc::mem_fun(*this,&studio::Dialog_Setup::on_gamma_g_change));
-
-	Gtk::Scale* scale_gamma_b(manage(new Gtk::Scale(adj_gamma_b)));
-	attach_label(pi.grid, _("Blue"), ++row);
-	pi.grid->attach(*scale_gamma_b, 1, row, 1, 1);
-	scale_gamma_b->set_hexpand(true);
-	adj_gamma_b->signal_value_changed().connect(sigc::mem_fun(*this,&studio::Dialog_Setup::on_gamma_b_change));
-
-	attach_label(pi.grid, _("Black Level"), ++row);
-	pi.grid->attach(black_level_selector, 1, row, 1, 1);
-	black_level_selector.set_hexpand(true);
-	black_level_selector.signal_value_changed().connect(sigc::mem_fun(*this,&studio::Dialog_Setup::on_black_level_change));
-
-	//attach_label(pi.grid,_("Red-Blue Level"), ++row);
-	//pi.grid->attach(red_blue_level_selector, 1, row, 1, 1);
-	//red_blue_level_selector.set_hexpand(true);
-	//red_blue_level_selector.signal_value_changed().connect(sigc::mem_fun(*this,&studio::Dialog_Setup::on_red_blue_level_change));
-}
-
 void
 Dialog_Setup::create_system_page(PageInfo pi)
 {
@@ -180,7 +126,6 @@ Dialog_Setup::create_system_page(PageInfo pi)
 	// System _ Units section
 	attach_label_section(pi.grid, _("Units"), row);
 	// System - 0 Timestamp
-	timestamp_menu=manage(new class Gtk::Menu());
 	attach_label(pi.grid, _("Timestamp"), ++row);
 	pi.grid->attach(timestamp_comboboxtext, 1, row, 1, 1);
 	timestamp_comboboxtext.set_hexpand(true);
@@ -229,7 +174,7 @@ Dialog_Setup::create_system_page(PageInfo pi)
 	pi.grid->attach(*recent_files_spinbutton, 1, row, 1, 1);
 
 	// System - Auto backup interval
-	attach_label_section(pi.grid, _("Auto Backup"), ++row);
+	attach_label_section(pi.grid, _("Autosave"), ++row);
 	pi.grid->attach(toggle_autobackup, 1, row, 1, 1);
 	toggle_autobackup.set_hexpand(false);
 	toggle_autobackup.set_halign(Gtk::ALIGN_START);
@@ -271,17 +216,10 @@ Dialog_Setup::create_system_page(PageInfo pi)
 		++row;
 	}
 	// System - 11 enable_experimental_features
-	//attach_label(pi.grid, _("Experimental features (restart needed)"), ++row);
-	//pi.grid->attach(toggle_enable_experimental_features, 1, row, 1, 1);
-	//toggle_enable_experimental_features.set_hexpand(true);
-
-#ifdef SINGLE_THREADED
-	// System - 12 single_threaded
-	attach_label_section(pi.grid, _("Single thread only (CPUs)"), ++row);
-	pi.grid->attach(toggle_single_threaded, 1, row, 1, 1);
-	toggle_single_threaded.set_hexpand(false);
-	toggle_single_threaded.set_halign(Gtk::ALIGN_START);
-#endif
+	attach_label_section(pi.grid, _("Experimental features (requires restart)"), ++row);
+	pi.grid->attach(toggle_enable_experimental_features, 1, row, 1, 1);
+	toggle_enable_experimental_features.set_halign(Gtk::ALIGN_START);
+	toggle_enable_experimental_features.set_hexpand(false);
 
 	// signal for change resume
 	auto_backup_interval.signal_changed().connect(
@@ -298,6 +236,10 @@ Dialog_Setup::create_document_page(PageInfo pi)
 	 *  prefix  ___________________
 	 *  fps   [_]                    [FPS]
 	 *  size  H[_]xW[_]      [resolutions]
+	 * DEFAULT BACKGROUND
+	 * (*) None (Transparent)
+	 * ( ) Solid Color         [colorbutton]
+	 * ( ) Image               [file path  ]
 	 *
 	 *
 	 *
@@ -388,6 +330,63 @@ Dialog_Setup::create_document_page(PageInfo pi)
 	size_template_combo->prepend(DEFAULT_PREDEFINED_SIZE);
 
 	fps_template_combo->prepend(DEFAULT_PREDEFINED_FPS);
+
+	attach_label_section(pi.grid, _("Default Background"), ++row);
+	//attach_label(pi.grid, _("Name prefix"), ++row);
+	//pi.grid->attach(textbox_custom_filename_prefix, 1, row, 2, 1);
+	//textbox_custom_filename_prefix.set_tooltip_text( _("File name prefix for the new created document"));
+	//textbox_custom_filename_prefix.set_hexpand(true);
+
+	//Gtk::RadioButton::Group group_def_background;
+	def_background_none.set_label(_("None (Transparent)"));
+	def_background_none.set_group(group_def_background);
+	pi.grid->attach(def_background_none,  0, ++row, 1, 1);
+	def_background_none.signal_clicked().connect(sigc::mem_fun(*this, &studio::Dialog_Setup::on_def_background_type_changed) );
+
+	def_background_color.set_label(_("Solid Color"));
+	def_background_color.set_group(group_def_background);
+	pi.grid->attach(def_background_color, 0, ++row, 1, 1);
+    def_background_color.signal_clicked().connect(sigc::mem_fun(*this, &studio::Dialog_Setup::on_def_background_type_changed) );
+
+	Gdk::RGBA m_color;
+	m_color.set_rgba( App::default_background_layer_color.get_r(),
+					  App::default_background_layer_color.get_g(),
+					  App::default_background_layer_color.get_b(),
+					  App::default_background_layer_color.get_a());
+	def_background_color_button.set_rgba(m_color);
+	pi.grid->attach(def_background_color_button, 1,   row, 1, 1);
+	def_background_color_button.signal_color_set().connect(sigc::mem_fun(*this, &studio::Dialog_Setup::on_def_background_color_changed) );
+
+	def_background_image.set_label(_("Image"));
+	def_background_image.set_group(group_def_background);
+	pi.grid->attach(def_background_image,      0, ++row, 1, 1);
+	def_background_image.signal_clicked().connect(sigc::mem_fun(*this, &studio::Dialog_Setup::on_def_background_type_changed) );
+	//<!- Button to select the image
+	fcbutton_image.set_title(_("Select"));
+	fcbutton_image.set_action(Gtk::FILE_CHOOSER_ACTION_OPEN);
+	fcbutton_image.set_filename(App::default_background_layer_image);
+	/*
+	filter_images.set_name(_("Images (*.bmp,*.jpg,*.jpeg,*.png,*.svg,*.lst)"));
+		filter_images.add_pattern("*.bmp");
+		filter_images.add_pattern("*.jpg");
+		filter_images.add_pattern("*.jpeg");
+		filter_images.add_pattern("*.png");
+		filter_images.add_pattern("*.svg");
+		filter_images.add_pattern("*.lst");
+		filter_any.set_name(_("Any file (*.*)"));
+		filter_any.add_pattern("*.*");
+
+	fcbutton_image.add_filter(filter_images);
+	fcbutton_image.add_filter(filter_any);
+	*/
+	//-> Button to select the image
+	pi.grid->attach(fcbutton_image,            1,   row, 2, 1);
+	fcbutton_image.signal_file_set().connect(sigc::mem_fun(*this, &studio::Dialog_Setup::on_def_background_image_set) );
+
+	if (App::default_background_layer_type == "none")        def_background_none.set_active();
+	if (App::default_background_layer_type == "solid_color") def_background_color.set_active();
+	if (App::default_background_layer_type == "image")       def_background_image.set_active();
+
 }
 
 void
@@ -399,7 +398,8 @@ Dialog_Setup::create_editing_page(PageInfo pi)
 	 * OTHER
 	 *  [x] Linear color
 	 *  [x] Restrict radius
-	 *
+	 * EDIT IN EXTERNAL
+	 * 	Preferred image editor [image_editor_path] (choose..)
 	 *
 	 */
 
@@ -417,25 +417,72 @@ Dialog_Setup::create_editing_page(PageInfo pi)
 	// Editing Other section
 	attach_label_section(pi.grid, _("Other"), ++row);
 
-	// Editing - Visually Linear Color Selection
-	attach_label(pi.grid,_("Visually linear color selection"), ++row);
-	pi.grid->attach(toggle_use_colorspace_gamma, 1, row, 1, 1);
-	toggle_use_colorspace_gamma.set_halign(Gtk::ALIGN_START);
-	toggle_use_colorspace_gamma.set_hexpand(false);
-	toggle_use_colorspace_gamma.set_tooltip_text(_("Color output is non-linear, if 0 \
-is black and 100 is white, then 50 is only about 22 percent of the brightness \
-of white, rather than 50% as you might expect. \
-Option (ON by default) to make sure that if you ask for 50, you get 50% of the brightness of white."));
-
-	// Editing - Restrict Really-valued Handles to Top Right Quadrant
-	attach_label(pi.grid,_("Restrict really-valued handles to top right quadrant"), ++row);
+	// Editing - Restrict Real-value Handles to Top Right Quadrant
+	attach_label(pi.grid,_("Restrict real value handles to top right quadrant"), ++row);
 	pi.grid->attach(toggle_restrict_radius_ducks, 1, row, 1, 1);
-	toggle_restrict_radius_ducks.set_halign(Gtk::ALIGN_END);
+	toggle_restrict_radius_ducks.set_halign(Gtk::ALIGN_START);
 	toggle_restrict_radius_ducks.set_hexpand(false);
-	toggle_restrict_radius_ducks.set_tooltip_text("Restrict the position of the handle \
+	toggle_restrict_radius_ducks.set_tooltip_text(_("Restrict the position of the handle \
 (especially for radius) to be in the top right quadrant of the 2D space. Allow to set \
 the real value to any number and also easily reach the value of 0.0 just \
-dragging the handle to the left bottom part of your 2D space.");
+dragging the handle to the left bottom part of your 2D space."));
+
+	attach_label_section(pi.grid, _("Edit in external"), ++row);
+
+	attach_label(pi.grid,_("Preferred image editor"), ++row);
+
+	//create a button that will open the filechooserdialog to select image editor
+	Gtk::Button *choose_button(manage(new class Gtk::Button(Gtk::StockID(_("Choose...")))));
+	choose_button->show();
+	choose_button->set_tooltip_text(_("Choose the preferred Image editor for Edit in external tool option"));
+	
+	//create a function to launch the dialog
+	choose_button->signal_clicked().connect(sigc::mem_fun(*this,&Dialog_Setup::on_choose_editor_pressed));
+	pi.grid->attach(image_editor_path_entry, 1, row, 1, 1);
+	pi.grid->attach(*choose_button, 2,row,1,1);
+	image_editor_path_entry.set_hexpand(true);
+	image_editor_path_entry.set_text(App::image_editor_path);
+	
+}
+
+
+void
+Dialog_Setup::on_choose_editor_pressed()
+{
+	//set the image editor path = filepath from dialog
+	String filepath = image_editor_path_entry.get_text();
+	if (select_path_dialog(_("Select Editor"), filepath)) {
+		image_editor_path_entry.set_text(filepath);
+		App::image_editor_path = filepath;
+	}
+}
+
+bool 
+Dialog_Setup::select_path_dialog(const std::string &title, std::string &filepath)
+{
+	Gtk::FileChooserDialog *dialog = new Gtk::FileChooserDialog(*App::main_window,title, Gtk::FILE_CHOOSER_ACTION_OPEN);
+	dialog->set_transient_for(*App::main_window);
+	#ifdef WIN32
+	dialog->set_current_folder("C:\\Program Files");
+
+	#elif defined(__APPLE__)
+    dialog->set_current_folder("/Applications");
+
+	#else
+    	dialog->set_current_folder("/usr/bin");
+	#endif
+
+	//Add response buttons the the dialog:
+	dialog->add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL);
+	dialog->add_button(_("Select"), Gtk::RESPONSE_OK);
+  	if(dialog->run() == Gtk::RESPONSE_OK) {
+		filepath = dialog->get_filename();
+		filepath = absolute_path(filepath);	//get the absolute path
+		delete dialog;
+		return true;
+	}
+	delete dialog;
+	return false;
 }
 
 void
@@ -444,9 +491,8 @@ Dialog_Setup::create_render_page(PageInfo pi)
 	/*---------Render------------------*\
 	 *
 	 *  sequence separator _________
-	 *   navigator [ Legacy ]
 	 *   workarea  [ Legacy ]
-	 *
+	 *   play sound on render done  [x| ]
 	 *
 	 */
 
@@ -455,24 +501,41 @@ Dialog_Setup::create_render_page(PageInfo pi)
 	attach_label(pi.grid, _("Image Sequence Separator String"), row);
 	pi.grid->attach(image_sequence_separator, 1, row, 1, 1);
 	image_sequence_separator.set_hexpand(true);
-	// Render - Navigator
-	attach_label(pi.grid, _("Navigator renderer"), ++row);
-	pi.grid->attach(navigator_renderer_combo, 1, row, 1, 1);
+
 	// Render - WorkArea
 	attach_label(pi.grid, _("WorkArea renderer"), ++row);
 	pi.grid->attach(workarea_renderer_combo, 1, row, 1, 1);
+	// Render - Render Done sound
+	attach_label(pi.grid, _("Chime on render done"), ++row);
+	pi.grid->attach(toggle_play_sound_on_render_done, 1, row, 1, 1);
+	toggle_play_sound_on_render_done.set_halign(Gtk::ALIGN_START);
+	toggle_play_sound_on_render_done.set_hexpand(false);
+	toggle_play_sound_on_render_done.set_tooltip_text(_("A chime is played when render has finished."));
+	toggle_play_sound_on_render_done.property_active().signal_changed().connect(
+			sigc::mem_fun(*this, &Dialog_Setup::on_play_sound_on_render_done_changed));
 
 	synfig::rendering::Renderer::Handle default_renderer = synfig::rendering::Renderer::get_renderer("");
-	navigator_renderer_combo.append("", String() + _("Default") + " - " + default_renderer->get_name());
 	workarea_renderer_combo.append("", String() + _("Default") + " - " + default_renderer->get_name());
 	typedef std::map<synfig::String, synfig::rendering::Renderer::Handle> RendererMap;
 	const RendererMap &renderers = synfig::rendering::Renderer::get_renderers();
 	for(RendererMap::const_iterator i = renderers.begin(); i != renderers.end(); ++i)
 	{
 		assert(!i->first.empty());
-		navigator_renderer_combo.append(i->first, i->second->get_name());
 		workarea_renderer_combo.append(i->first, i->second->get_name());
 	}
+
+	attach_label(pi.grid, _("Preview Background Color"), ++row);
+
+	Gdk::RGBA m_color;
+	m_color.set_rgba( App::preview_background_color.get_r(),
+	                  App::preview_background_color.get_g(),
+	                  App::preview_background_color.get_b(),
+	                  App::preview_background_color.get_a());
+	preview_background_color_button.set_rgba(m_color);
+	pi.grid->attach(preview_background_color_button, 1, row, 1, 1);
+	preview_background_color_button.signal_color_set().connect(
+		sigc::mem_fun(*this, &studio::Dialog_Setup::on_preview_background_color_changed) );
+
 }
 
 void
@@ -495,6 +558,7 @@ Dialog_Setup::create_interface_page(PageInfo pi)
 
 	static const char* languages[][2] = {
 		#include <languages.inc.c>
+		#include <gdkmm-3.0/gdkmm/rgba.h>
 		{ NULL, NULL } // final entry without comma to avoid misunderstanding
 	};
 
@@ -549,7 +613,7 @@ Dialog_Setup::create_interface_page(PageInfo pi)
 	toggle_handle_tooltip_transformation.set_halign(Gtk::ALIGN_START);
 	toggle_handle_tooltip_transformation.set_hexpand(false);
 	toggle_handle_tooltip_transformation.property_active().signal_changed().connect(
-			sigc::mem_fun(*this, &Dialog_Setup::on_tooltip_transformation_changed));
+		sigc::mem_fun(*this, &Dialog_Setup::on_tooltip_transformation_changed));
 
 	attach_label(pi.grid, _("Name"), ++row);// HANDLE_TOOLTIP_TRANSFO_NAME
 	pi.grid->attach(toggle_handle_tooltip_transfo_name, 1, row, 1, 1);
@@ -565,17 +629,17 @@ Dialog_Setup::create_interface_page(PageInfo pi)
 			sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_LANGUAGE));
 	//TODO signal change on value
 	//toggle_use_dark_theme.signal_changed().connect(
-	//		sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_THEME));
+	//	sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_THEME));
 	toggle_handle_tooltip_widthpoint.property_active().signal_changed().connect(
-			sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
+		sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
 	toggle_handle_tooltip_radius.property_active().signal_changed().connect(
-			sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
+		sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
 	toggle_handle_tooltip_transformation.property_active().signal_changed().connect(
-			sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
+		sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
 	toggle_handle_tooltip_transfo_name.property_active().signal_changed().connect(
-			sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
+		sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
 	toggle_handle_tooltip_transfo_value.property_active().signal_changed().connect(
-			sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
+		sigc::bind<int> (sigc::mem_fun(*this, &Dialog_Setup::on_value_change), CHANGE_UI_HANDLE_TOOLTIP));
 }
 
 void
@@ -589,54 +653,39 @@ Dialog_Setup::on_restore_pressed()
 void
 Dialog_Setup::on_apply_pressed()
 {
-	App::gamma.set_all(
-		1.0/adj_gamma_r->get_value(),
-		1.0/adj_gamma_g->get_value(),
-		1.0/adj_gamma_b->get_value(),
-		black_level_selector.get_value(),
-		red_blue_level_selector.get_value());
-
 	App::set_max_recent_files((int)adj_recent_files->get_value());
 
 	// Set the time format
 	App::set_time_format(get_time_format());
 
-	// Set the use_colorspace_gamma flag
-	App::use_colorspace_gamma=toggle_use_colorspace_gamma.get_active();
-
-#ifdef SINGLE_THREADED
-	// Set the single_threaded flag
-	App::single_threaded=toggle_single_threaded.get_active();
-#endif
-
 	//if(pref_modification_flag&CHANGE_AUTOBACKUP)
 	// TODO catch change event on auto_backup_interval before use CHANGE_AUTOBACKUP
 	{
 		// Set the auto backup status
-		App::auto_recover->enable(toggle_autobackup.get_active());
+		App::auto_recover->set_enabled(toggle_autobackup.get_active());
 		// Set the auto backup interval
-		App::auto_recover->set_timeout(auto_backup_interval.get_value() * 1000);
+		App::auto_recover->set_timeout_ms(auto_backup_interval.get_value() * 1000);
 	}
 
-	App::distance_system=Distance::System(widget_enum->get_value());
+	App::distance_system              = Distance::System(widget_enum->get_value());
 
 	// Set the restrict_radius_ducks flag
-	App::restrict_radius_ducks=toggle_restrict_radius_ducks.get_active();
+	App::restrict_radius_ducks        = toggle_restrict_radius_ducks.get_active();
 
 	// Set the resize_imported_images flag
-	App::resize_imported_images=toggle_resize_imported_images.get_active();
+	App::resize_imported_images       = toggle_resize_imported_images.get_active();
 
 	// Set the experimental features flag
-	App::enable_experimental_features=toggle_enable_experimental_features.get_active();
+	App::enable_experimental_features = toggle_enable_experimental_features.get_active();
 
 	// Set the dark theme flag
-	App::use_dark_theme=toggle_use_dark_theme.get_active();
+	App::use_dark_theme               = toggle_use_dark_theme.get_active();
 	App::apply_gtk_settings();
 
 	// Set file toolbar flag
 	App::show_file_toolbar=toggle_show_file_toolbar.get_active();
 
-	//! TODO Create Change mecanism has Class for being used elsewhere
+	//! TODO Create Change mechanism has Class for being used elsewhere
 	// Set the preferred brush path(s)
 	if (pref_modification_flag&CHANGE_BRUSH_PATH)
 	{
@@ -644,10 +693,10 @@ Dialog_Setup::on_apply_pressed()
 		int path_count = 0;
 
 		Glib::RefPtr<Gtk::ListStore> liststore = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(
-				listviewtext_brushes_path->get_model());
+			listviewtext_brushes_path->get_model());
 
 		for(Gtk::TreeIter ui_iter = liststore->children().begin();
-				ui_iter!=liststore->children().end();ui_iter++)
+			ui_iter!=liststore->children().end();ui_iter++)
 		{
 			const Gtk::TreeRow row = *(ui_iter);
 			// TODO utf_8 path : care to other locale than english ?
@@ -659,52 +708,55 @@ Dialog_Setup::on_apply_pressed()
 	}
 
 	// Set the preferred file name prefix
-	App::custom_filename_prefix=textbox_custom_filename_prefix.get_text();
+	App::custom_filename_prefix = textbox_custom_filename_prefix.get_text();
+
+	// Set the preferred image editor
+	App::image_editor_path = image_editor_path_entry.get_text();
 
 	// Set the preferred new Document X dimension
-	App::preferred_x_size=int(adj_pref_x_size->get_value());
+	App::preferred_x_size       = int(adj_pref_x_size->get_value());
 
 	// Set the preferred new Document Y dimension
-	App::preferred_y_size=int(adj_pref_y_size->get_value());
+	App::preferred_y_size       = int(adj_pref_y_size->get_value());
 
 	// Set the preferred Predefined size
-	App::predefined_size=size_template_combo->get_active_text();
+	App::predefined_size        = size_template_combo->get_active_text();
 
 	// Set the preferred Predefined fps
-	App::predefined_fps=fps_template_combo->get_active_text();
+	App::predefined_fps         = fps_template_combo->get_active_text();
 
 	// Set the preferred FPS
-	App::preferred_fps=Real(adj_pref_fps->get_value());
+	App::preferred_fps          = Real(adj_pref_fps->get_value());
 
 	// Set the preferred image sequence separator
-	App::sequence_separator=image_sequence_separator.get_text();
+	App::sequence_separator     = image_sequence_separator.get_text();
 
-	// Set the navigator render flag
-	App::navigator_renderer=navigator_renderer_combo.get_active_id();
+	// Set the workarea render and navigator render flag
+	App::navigator_renderer = App::workarea_renderer  = workarea_renderer_combo.get_active_id();
 
-	// Set the workarea render flag
-	App::workarea_renderer=workarea_renderer_combo.get_active_id();
+	// Set the use of a render done sound
+	App::use_render_done_sound  = toggle_play_sound_on_render_done.get_active();
 
 	// Set ui language
-	if (pref_modification_flag&CHANGE_UI_LANGUAGE)
+	if (pref_modification_flag & CHANGE_UI_LANGUAGE)
 		App::ui_language = ui_language_combo.get_active_id().c_str();
 
-	if (pref_modification_flag&CHANGE_UI_HANDLE_TOOLTIP)
+	if (pref_modification_flag & CHANGE_UI_HANDLE_TOOLTIP)
 	{
-		// Set ui tooltip on widht point
+		// Set ui tooltip on width point
 		App::ui_handle_tooltip_flag=toggle_handle_tooltip_widthpoint.get_active()?Duck::STRUCT_WIDTHPOINT:Duck::STRUCT_NONE;
 		// Set ui tooltip on radius
-		App::ui_handle_tooltip_flag|=toggle_handle_tooltip_radius.get_active()?Duck::STRUCT_RADIUS:Duck::STRUCT_NONE;
+		App::ui_handle_tooltip_flag |= toggle_handle_tooltip_radius.get_active()?Duck::STRUCT_RADIUS:Duck::STRUCT_NONE;
 		// Set ui tooltip on transformation
 		if(toggle_handle_tooltip_transformation.get_active())
 		{
 			if(toggle_handle_tooltip_transfo_name.get_active())
 			{
-				App::ui_handle_tooltip_flag|=Duck::STRUCT_TRANSFORMATION;
+				App::ui_handle_tooltip_flag |= Duck::STRUCT_TRANSFORMATION;
 			}
 			if(toggle_handle_tooltip_transfo_value.get_active())
 			{
-				App::ui_handle_tooltip_flag|=Duck::STRUCT_TRANSFO_BY_VALUE;
+				App::ui_handle_tooltip_flag |= Duck::STRUCT_TRANSFO_BY_VALUE;
 			}
 		}
 	}
@@ -721,46 +773,6 @@ Dialog_Setup::on_apply_pressed()
 
 }
 
-void
-Dialog_Setup::on_gamma_r_change()
-{
-	gamma_pattern.set_gamma_r(1.0/adj_gamma_r->get_value());
-	gamma_pattern.refresh();
-	gamma_pattern.queue_draw();
-}
-
-void
-Dialog_Setup::on_gamma_g_change()
-{
-	gamma_pattern.set_gamma_g(1.0/adj_gamma_g->get_value());
-	gamma_pattern.refresh();
-	gamma_pattern.queue_draw();
-}
-
-void
-Dialog_Setup::on_gamma_b_change()
-{
-	gamma_pattern.set_gamma_b(1.0/adj_gamma_b->get_value());
-	gamma_pattern.refresh();
-	gamma_pattern.queue_draw();
-}
-
-void
-Dialog_Setup::on_black_level_change()
-{
-	gamma_pattern.set_black_level(black_level_selector.get_value());
-	gamma_pattern.refresh();
-	gamma_pattern.queue_draw();
-}
-
-void
-Dialog_Setup::on_red_blue_level_change()
-{
-	gamma_pattern.set_red_blue_level(red_blue_level_selector.get_value());
-	gamma_pattern.refresh();
-	gamma_pattern.queue_draw();
-}
-
 void
 Dialog_Setup::on_size_template_combo_change()
 {
@@ -819,7 +831,52 @@ void
 Dialog_Setup::on_autobackup_changed()
 {
 	auto_backup_interval.set_sensitive(toggle_autobackup.get_active());
-	App::auto_recover->enable(toggle_autobackup.get_active());
+	App::auto_recover->set_enabled(toggle_autobackup.get_active());
+}
+
+void
+Dialog_Setup::on_play_sound_on_render_done_changed()
+{
+	App::use_render_done_sound = toggle_play_sound_on_render_done.get_active();
+}
+
+void
+Dialog_Setup::on_def_background_type_changed()
+{
+	if (def_background_none.get_active())  App::default_background_layer_type = "none";
+	if (def_background_color.get_active()) App::default_background_layer_type = "solid_color";
+	if (def_background_image.get_active()) App::default_background_layer_type = "image";
+}
+
+void
+Dialog_Setup::on_def_background_color_changed()
+{
+	Gdk::RGBA m_color = def_background_color_button.get_rgba();
+
+	App::default_background_layer_color =
+		synfig::Color(m_color.get_red(),
+		              m_color.get_green(),
+		              m_color.get_blue(),
+		              m_color.get_alpha());
+}
+
+void
+Dialog_Setup::on_def_background_image_set()
+{
+	App::default_background_layer_image = fcbutton_image.get_filename();
+}
+
+void
+Dialog_Setup::on_preview_background_color_changed()
+{
+	Gdk::RGBA m_color = preview_background_color_button.get_rgba();
+
+	App::preview_background_color =
+		synfig::Color(m_color.get_red(),
+		              m_color.get_green(),
+		              m_color.get_blue(),
+		              m_color.get_alpha());
+	//studio::Widget_Preview::
 }
 
 void
@@ -834,22 +891,7 @@ Dialog_Setup::refresh()
 {
 	refreshing = true;
 	pref_modification_flag = CHANGE_NONE;
-	// Refresh the temporary gamma; do this before adjusting the sliders,
-	// or variables will be used before their initialization.
-	gamma_pattern.set_gamma_r(App::gamma.get_gamma_r());
-	gamma_pattern.set_gamma_g(App::gamma.get_gamma_g());
-	gamma_pattern.set_gamma_b(App::gamma.get_gamma_b());
-	gamma_pattern.set_black_level(App::gamma.get_black_level());
-	gamma_pattern.set_red_blue_level(App::gamma.get_red_blue_level());
-
-	adj_gamma_r->set_value(1.0/App::gamma.get_gamma_r());
-	adj_gamma_g->set_value(1.0/App::gamma.get_gamma_g());
-	adj_gamma_b->set_value(1.0/App::gamma.get_gamma_b());
-	black_level_selector.set_value(App::gamma.get_black_level());
-	red_blue_level_selector.set_value(App::gamma.get_red_blue_level());
-
-	gamma_pattern.refresh();
-
+	
 	adj_recent_files->set_value(App::get_max_recent_files());
 
 	// Refresh the time format
@@ -857,17 +899,10 @@ Dialog_Setup::refresh()
 
 	widget_enum->set_value(App::distance_system);
 
-	// Refresh the status of the use_colorspace_gamma flag
-	toggle_use_colorspace_gamma.set_active(App::use_colorspace_gamma);
-
-#ifdef SINGLE_THREADED
-	// Refresh the status of the single_threaded flag
-	toggle_single_threaded.set_active(App::single_threaded);
-#endif
-	toggle_autobackup.set_active(App::auto_recover->get_enable());
+	toggle_autobackup.set_active(App::auto_recover->get_enabled());
 	// Refresh the value of the auto backup interval
-	auto_backup_interval.set_value(App::auto_recover->get_timeout() / 1000);
-	auto_backup_interval.set_sensitive(App::auto_recover->get_enable());
+	auto_backup_interval.set_value(App::auto_recover->get_timeout_ms() / 1000);
+	auto_backup_interval.set_sensitive(App::auto_recover->get_enabled());
 
 	// Refresh the status of the restrict_radius_ducks flag
 	toggle_restrict_radius_ducks.set_active(App::restrict_radius_ducks);
@@ -881,13 +916,19 @@ Dialog_Setup::refresh()
 	// Refresh the status of the theme flag
 	toggle_use_dark_theme.set_active(App::use_dark_theme);
 
+	// Refresh the status of the render done sound flag
+	toggle_play_sound_on_render_done.set_active(App::use_render_done_sound);
+
 	// Refresh the status of file toolbar flag
 	toggle_show_file_toolbar.set_active(App::show_file_toolbar);
 
+	// Refresh the preferred image editor path
+	image_editor_path_entry.set_text(App::image_editor_path);
+
 	// Refresh the brush path(s)
 	Glib::RefPtr<Gtk::ListStore> liststore = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(
 			listviewtext_brushes_path->get_model());
-	//! Keep "brushes_path" preferences entry for backward compatibilty (15/12 - v1.0.3)
+	//! Keep "brushes_path" preferences entry for backward compatibility (15/12 - v1.0.3)
 	//! Now brush path(s) are hold by input preferences : brush.path_count & brush.path_%d
 	String value;
 	Gtk::TreeIter ui_iter;
@@ -940,9 +981,6 @@ Dialog_Setup::refresh()
 	//Refresh the sequence separator
 	image_sequence_separator.set_text(App::sequence_separator);
 
-	// Refresh the status of the navigator_renderer
-	navigator_renderer_combo.set_active_id(App::navigator_renderer);
-
 	// Refresh the status of the workarea_renderer
 	workarea_renderer_combo.set_active_id(App::workarea_renderer);
 
@@ -970,225 +1008,11 @@ Dialog_Setup::refresh()
 	refreshing = false;
 }
 
-GammaPattern::GammaPattern():
-	gamma_r(),
-	gamma_g(),
-	gamma_b(),
-	black_level(),
-	red_blue_level(),
-	tile_w(80),
-	tile_h(80)
-{
-	set_size_request(tile_w*4,tile_h*3);
-}
-
-GammaPattern::~GammaPattern()
-{
-}
-
-void
-GammaPattern::refresh()
-{
-	black[0].set_rgb_p(
-		r_F32_to_F32(0.0),
-		g_F32_to_F32(0.0),
-		b_F32_to_F32(0.0)
-	);
-	white[0].set_rgb_p(
-		r_F32_to_F32(1.0),
-		g_F32_to_F32(1.0),
-		b_F32_to_F32(1.0)
-	);
-	gray50[0].set_rgb_p(
-		r_F32_to_F32(0.5),
-		g_F32_to_F32(0.5),
-		b_F32_to_F32(0.5)
-	);
-	gray25[0].set_rgb_p(
-		r_F32_to_F32(0.25),
-		g_F32_to_F32(0.25),
-		b_F32_to_F32(0.25)
-	);
-
-	// Reds
-	black[1].set_rgb(black[0].get_red(),0,0);
-	gray25[1].set_rgb(gray25[0].get_red(),0,0);
-	gray50[1].set_rgb(gray50[0].get_red(),0,0);
-	white[1].set_rgb(white[0].get_red(),0,0);
-
-	// Greens
-	black[2].set_rgb(0,black[0].get_green(),0);
-	gray25[2].set_rgb(0,gray25[0].get_green(),0);
-	gray50[2].set_rgb(0,gray50[0].get_green(),0);
-	white[2].set_rgb(0,white[0].get_green(),0);
-
-	// blues
-	black[3].set_rgb(0,0,black[0].get_blue());
-	gray25[3].set_rgb(0,0,gray25[0].get_blue());
-	gray50[3].set_rgb(0,0,gray50[0].get_blue());
-	white[3].set_rgb(0,0,white[0].get_blue());
-}
-
-bool
-GammaPattern::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
-{
-	int i;
-	Gdk::Color trueblack("#000000");
-
-	int stride = Cairo::ImageSurface::format_stride_for_width(Cairo::FORMAT_A1, 2);
-	std::vector<unsigned char> hlines(2*stride, 0);
-	hlines[0] = 3;
-	Cairo::RefPtr<Cairo::ImageSurface> stipple_mask_img = Cairo::ImageSurface::create(&hlines.front(), Cairo::FORMAT_A1, 2, 2, stride);
-
-	// 50% Pattern
-	for(i=0;i<4;i++)
-	{
-        cr->set_source_rgb(black[i].get_red_p(), black[i].get_green_p(), black[i].get_blue_p());
-        cr->rectangle(i*tile_w, 0, tile_w, tile_h);
-        cr->fill();
-
-        cr->set_source_rgb(white[i].get_red_p(), white[i].get_green_p(), white[i].get_blue_p());
-        cr->mask(stipple_mask_img, 0, 0);
-        cr->rectangle(i*tile_w, 0, tile_w, tile_h);
-        cr->fill();
-
-        cr->set_source_rgb(gray50[i].get_red_p(), gray50[i].get_green_p(), gray50[i].get_blue_p());
-        cr->rectangle(i*tile_w+tile_w/4, tile_h/4, tile_w-tile_w/2, tile_h-tile_h/2);
-        cr->fill();
-	}
-
-	// 25% Pattern
-	for(i=0;i<4;i++)
-	{
-        cr->set_source_rgb(black[i].get_red_p(), black[i].get_green_p(), black[i].get_blue_p());
-        cr->rectangle(i*tile_w, tile_h, tile_w, tile_h);
-        cr->fill();
-
-        cr->set_source_rgb(gray50[i].get_red_p(), gray50[i].get_green_p(), gray50[i].get_blue_p());
-        cr->mask(stipple_mask_img, 0, 0);
-        cr->rectangle(i*tile_w, tile_h, tile_w, tile_h);
-        cr->fill();
-
-        cr->set_source_rgb(gray25[i].get_red_p(), gray25[i].get_green_p(), gray25[i].get_blue_p());
-        cr->rectangle(i*tile_w+tile_w/4, tile_h+tile_h/4, tile_w-tile_w/2, tile_h-tile_h/2);
-        cr->fill();
-	}
-
-	// Black-level Pattern
-    cr->set_source_rgb(trueblack.get_red_p(), trueblack.get_green_p(), trueblack.get_blue_p());
-	cr->rectangle(0, tile_h*2, tile_w*4, tile_h);
-	cr->fill();
-
-	for(i=0;i<4;i++)
-	{
-        cr->set_source_rgb(black[i].get_red_p(), black[i].get_green_p(), black[i].get_blue_p());
-        cr->rectangle(i*tile_w+tile_w/4, tile_h*2+tile_h/4, tile_w-tile_w/2, tile_h-tile_h/2);
-        cr->fill();
-	}
-
-	return true;
-}
-
-
-BlackLevelSelector::BlackLevelSelector():
-	level()
-{
-	set_size_request(-1,24);
-
-	add_events(Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK);
-	add_events(Gdk::BUTTON1_MOTION_MASK);
-	add_events(Gdk::BUTTON1_MOTION_MASK);
-}
-
-BlackLevelSelector::~BlackLevelSelector()
-{
-}
-
-bool
-BlackLevelSelector::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
-{
-	const int w(get_width()),h(get_height());
-
-	Gdk::Color color;
-
-	int i;
-
-	// Draw the gradient
-	for(i=0;i<w;i++)
-	{
-		double c = (double)i/(double)(w-1);
-        cr->set_source_rgb(c,c,c);
-        cr->rectangle(i, 0, 1, h);
-        cr->fill();
-	}
-
-	// Draw a frame
-	cr->set_source_rgb(0,0,0);
-	cr->rectangle(0, 0, w-1, h-1);
-	cr->stroke();
-
-	// Draw the position of the current value
-	i=(int)(level*w+0.5);
-	cr->set_source_rgb(1,0,0);
-	cr->rectangle(i, 1, 1, h-1);
-	cr->fill();
-
-	// Print out the value
-	Glib::RefPtr<Pango::Layout> layout(Pango::Layout::create(get_pango_context()));
-	layout->set_text(etl::strprintf("%0.01f%%",level*100.0f));
-	layout->set_alignment(Pango::ALIGN_CENTER);
-	cr->set_source_rgb(0.627,1,0);
-	cr->move_to(w/2, 4);
-	layout->show_in_cairo_context(cr);
-
-	return true;
-}
-
-
-
-bool
-BlackLevelSelector::on_event(GdkEvent *event)
-{
-	int x(round_to_int(event->button.x));
-	//int y(round_to_int(event->button.y));
-
-    switch(event->type)
-    {
-	case GDK_MOTION_NOTIFY:
-		level=(float)x/(float)get_width();
-		if(level<0.0f)level=0.0f;
-		if(level>1.0f)level=1.0f;
-		signal_value_changed_();
-		queue_draw();
-		return true;
-		break;
-	case GDK_BUTTON_PRESS:
-	case GDK_BUTTON_RELEASE:
-		if(event->button.button==1)
-		{
-			level=(float)x/(float)get_width();
-			if(level<0.0f)level=0.0f;
-			if(level>1.0f)level=1.0f;
-			signal_value_changed_();
-			queue_draw();
-			return true;
-		}
-		break;
-	default:
-		break;
-	}
-
-	return false;
-}
-
-
 void
 Dialog_Setup::set_time_format(synfig::Time::Format x)
 {
 	time_format=x;
-	if (x <= Time::FORMAT_VIDEO)
-		timestamp_comboboxtext.set_active(0);
-	else if (x == (Time::FORMAT_NORMAL))
+	if (x == (Time::FORMAT_NORMAL))
 		timestamp_comboboxtext.set_active(1);
 	else if (x == (Time::FORMAT_NORMAL | Time::FORMAT_NOSPACES))
 		timestamp_comboboxtext.set_active(2);
@@ -1198,103 +1022,12 @@ Dialog_Setup::set_time_format(synfig::Time::Format x)
 		timestamp_comboboxtext.set_active(4);
 	else if (x == (Time::FORMAT_FRAMES))
 		timestamp_comboboxtext.set_active(5);
+	else if (x <= Time::FORMAT_VIDEO)
+		timestamp_comboboxtext.set_active(0);
 	else
 		timestamp_comboboxtext.set_active(1);
 }
 
-RedBlueLevelSelector::RedBlueLevelSelector():
-	level()
-{
-	set_size_request(-1,24);
-
-	add_events(Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK);
-	add_events(Gdk::BUTTON1_MOTION_MASK);
-	add_events(Gdk::BUTTON1_MOTION_MASK);
-}
-
-RedBlueLevelSelector::~RedBlueLevelSelector()
-{
-}
-
-bool
-RedBlueLevelSelector::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
-{
-	const int w(get_width()),h(get_height());
-
-	Gdk::Color color;
-
-	int i;
-
-	// Draw the gradient
-	for(i=0;i<w;i++)
-	{
-		float red_blue(((float(i)/float(w)+0.5f)-1.0f)/2.0f+1.0f);
-		float blue_red(2.0f-(red_blue));
-		if(red_blue>1.0f)red_blue=1.0f;
-		if(blue_red>1.0f)blue_red=1.0f;
-
-		cr->set_source_rgb(red_blue, sqrt(min(red_blue,blue_red)), blue_red);
-		cr->rectangle(i, 0, 1, h);
-		cr->fill();
-	}
-
-	// Draw a frame
-	cr->set_source_rgb(0,0,0);
-	cr->rectangle(0, 0, w-1, h-1);
-	cr->stroke();
-
-	// Draw the position of the current value
-	i=(int)(((level-1.0f)*2.0f+1.0f-0.5f)*w+0.5);
-	cr->set_source_rgb(0,1,0);
-	cr->rectangle(i, 1, 1, h-1);
-	cr->fill();
-
-	// Print out the value
-	Glib::RefPtr<Pango::Layout> layout(Pango::Layout::create(get_pango_context()));
-	layout->set_text(etl::strprintf("%0.02f",level));
-	layout->set_alignment(Pango::ALIGN_CENTER);
-	cr->set_source_rgb(0.627,1,0);
-	cr->move_to(w/2, 4);
-	layout->show_in_cairo_context(cr);
-
-	return true;
-}
-
-bool
-RedBlueLevelSelector::on_event(GdkEvent *event)
-{
-	int x(round_to_int(event->button.x));
-	//int y(round_to_int(event->button.y));
-
-    switch(event->type)
-    {
-	case GDK_MOTION_NOTIFY:
-		level=(((float)(x)/(float)get_width()+0.5)-1.0f)/2.0f+1.0f;
-		if(level<0.5f)level=0.5f;
-		if(level>1.5f)level=1.5f;
-		signal_value_changed_();
-		queue_draw();
-		return true;
-		break;
-	case GDK_BUTTON_PRESS:
-	case GDK_BUTTON_RELEASE:
-		if(event->button.button==1)
-		{
-			level=(((float)(x)/(float)get_width()+0.5)-1.0f)/2.0f+1.0f;
-			if(level<0.5f)level=0.5f;
-			if(level>1.5f)level=1.5f;
-			signal_value_changed_();
-			queue_draw();
-			return true;
-		}
-		break;
-	default:
-		break;
-	}
-
-	return false;
-}
-
 void
 Dialog_Setup::on_brush_path_add_clicked()
 {
