@@ -30,18 +30,23 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "docks/dockbook.h"
 #include "docks/dockable.h"
 #include "app.h"
 #include "docks/dockmanager.h"
 #include "docks/dockdroparea.h"
 
+#include <gtkmm/window.h>
 #include <gtkmm/image.h>
 #include <gtkmm/eventbox.h>
 #include <gtkmm/menu.h>
 #include <gtkmm/imagemenuitem.h>
 
-#include "general.h"
+#include <gui/localization.h>
+
+#include <gui/exception_guard.h>
 
 #include "canvasview.h"
 
@@ -78,22 +83,37 @@ DockBook::DockBook():
 	set_scrollable(true);
 	deleting_=false;
 
-	DockDropArea *dock_area = manage(new DockDropArea(this));
-	dock_area->show();
+	dock_area = manage(new DockDropArea(this));
+	dock_area->hide();
 	set_action_widget(dock_area, Gtk::PACK_END);
 }
 
 DockBook::~DockBook()
 {
-	DockManager::containers_to_remove_.erase(this);
 	deleting_=true;
 	clear();
+	DockManager::containers_to_remove_.erase(this);
 }
 
 void
 DockBook::clear()
 {
-	while(get_n_pages())
+	// here the point: get_n_pages is fails because this is not notebook type
+	// i didn't know why this happens, possibly because clear() is called from destructor
+	// and 'this' is already deleted. Or, this function maybe never work right.
+	// So here quick-hack again. Btw, as you can see from commented code later newly created 
+	// dockbook is works fine, so this situation is reqired more detailed investigation.
+	if (!GTK_IS_NOTEBOOK (this)) return; // because we always fail if 'this' is not notebook
+
+	/*Gtk::Notebook note;
+	int x = note.get_n_pages();
+
+	DockBook db;
+	x = db.get_n_pages();
+
+	const Gtk::Notebook* nb = (const Gtk::Notebook*)this;*/
+	//assert(GTK_IS_NOTEBOOK (nb));
+	while (this->get_n_pages())
 		remove(static_cast<Dockable&>(*get_nth_page(get_n_pages()-1)));
 }
 
@@ -179,6 +199,8 @@ void
 DockBook::present()
 {
 	show();
+	if (Gtk::Window *window = dynamic_cast<Gtk::Window*>(get_toplevel()))
+		window->present();
 }
 
 synfig::String
@@ -244,6 +266,7 @@ DockBook::set_contents(const synfig::String& x)
 bool
 DockBook::tab_button_pressed(GdkEventButton* event, Dockable* dockable)
 {
+	SYNFIG_EXCEPTION_GUARD_BEGIN()
 	CanvasView *canvas_view = dynamic_cast<CanvasView*>(dockable);
 	if (canvas_view && canvas_view != App::get_selected_canvas_view())
 		App::set_selected_canvas_view(canvas_view);
@@ -263,6 +286,7 @@ DockBook::tab_button_pressed(GdkEventButton* event, Dockable* dockable)
 	tabmenu->popup(event->button,gtk_get_current_event_time());
 
 	return true;
+	SYNFIG_EXCEPTION_GUARD_END_BOOL(true)
 }
 
 void
@@ -275,3 +299,11 @@ DockBook::on_switch_page(Gtk::Widget* page, guint page_num)
 	}
 	Notebook::on_switch_page(page, page_num);
 }
+
+void DockBook::set_dock_area_visibility(bool visible, DockBook* source)
+{
+	if (visible && source == this && get_n_pages() == 1)
+		return;
+
+	dock_area->set_visible(visible);
+}
