@@ -99,7 +99,8 @@
 #include "actions/valuedescskeletonlink.h"
 #include "actions/valuedesccreatechildbone.h"
 #include "actions/valuedescresetpose.h"
-
+#include "actions/valuedescbake.h"
+#include "actions/vectorization.h"
 #include "actions/waypointadd.h"
 #include "actions/waypointset.h"
 #include "actions/waypointsetsmart.h"
@@ -172,7 +173,7 @@ synfigapp::Action::Book *book_;
 
 #define ADD_ACTION(x) { BookEntry &be(book()[x::name__]); \
 	be.name=x::name__; \
-	be.local_name=dgettext("synfigstudio",x::local_name__); \
+	be.local_name=_(x::local_name__); \
 	be.version=x::version__; \
 	be.task=x::task__; \
 	be.priority=x::priority__; \
@@ -255,7 +256,8 @@ Action::Main::Main()
 	ADD_ACTION(Action::ValueDescSkeletonLink);
 	ADD_ACTION(Action::ValueDescCreateChildBone);
 	ADD_ACTION(Action::ValueDescResetPose);
-
+	ADD_ACTION(Action::ValueDescBake);
+	ADD_ACTION(Action::Vectorization);
 	ADD_ACTION(Action::WaypointAdd);
 	ADD_ACTION(Action::WaypointSet);
 	ADD_ACTION(Action::WaypointSetSmart);
@@ -283,7 +285,7 @@ Action::Main::Main()
 	ADD_ACTION(Action::CanvasDescriptionSet);
 	ADD_ACTION(Action::CanvasIdSet);
 	ADD_ACTION(Action::CanvasNameSet)
-	ADD_ACTION(Action::CanvasMetadataErase);;
+	ADD_ACTION(Action::CanvasMetadataErase);
 	ADD_ACTION(Action::CanvasMetadataSet);
 	ADD_ACTION(Action::CanvasRendDescSet);
 	ADD_ACTION(Action::CanvasAdd);
@@ -480,7 +482,7 @@ Super::perform()
 				throw;
 			}
 		}
-		catch(Error x)
+		catch(Error& x)
 		{
 			//synfig::info("%s:%d caught exception", __FILE__, __LINE__);
 			throw Error(x.get_type(),((*iter)->get_local_name()+": "+x.get_desc()).c_str());
