@@ -32,6 +32,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "layerparamset.h"
 #include "valuenodeconstset.h"
 #include "valuedescconnect.h"
@@ -61,9 +63,10 @@
 #include <synfig/valueoperations.h>
 #include <synfig/weightedvalue.h>
 #include <synfig/pair.h>
+#include <synfig/segment.h>
 #include <synfigapp/main.h>
 
-#include <synfigapp/general.h>
+#include <synfigapp/localization.h>
 
 #endif
 
@@ -276,7 +279,8 @@ Action::ValueDescSet::prepare()
 				action->set_param("canvas_interface",get_canvas_interface());
 				action->set_param("time",time);
 				action->set_param("new_value",values_list[i]);
-				action->set_param("value_desc",ValueDesc(value_desc.get_value_node(), i));
+				action->set_param("value_desc", ValueDesc(
+					LinkableValueNode::Handle::cast_dynamic(value_desc.get_value_node()), i ));
 
 				if(!action->is_ready())
 					throw Error(Error::TYPE_NOTREADY);
@@ -314,7 +318,8 @@ Action::ValueDescSet::prepare()
 				action->set_param("canvas_interface",get_canvas_interface());
 				action->set_param("time",time);
 				action->set_param("new_value",new_values_list[i]);
-				action->set_param("value_desc",ValueDesc(value_desc.get_value_node(), i));
+				action->set_param("value_desc", ValueDesc(
+					LinkableValueNode::Handle::cast_dynamic(value_desc.get_value_node()), i ));
 
 				if(!action->is_ready())
 					throw Error(Error::TYPE_NOTREADY);
@@ -663,7 +668,7 @@ Action::ValueDescSet::prepare()
 		else if(value.get_type() == type_real)
 			new_value = integer_value_node->get_inverse(time, value.get(Real()));
 		else
-			throw Error(_("Inverse manipulation of %s scale values not implemented in core."), value.type_name().c_str());
+			throw Error(_("Inverse manipulation of %s integer values not implemented in core."), value.type_name().c_str());
 		Action::Handle action(Action::create("ValueDescSet"));
 		if(!action)
 			throw Error(_("Unable to find action ValueDescSet (bug)"));
@@ -685,8 +690,10 @@ Action::ValueDescSet::prepare()
 			new_value = add_value_node->get_inverse(time, value.get(Angle()));
 		else if(value.get_type() == type_real)
 			new_value = add_value_node->get_inverse(time, value.get(Real()));
+		else if(value.get_type() == type_vector)
+			new_value = add_value_node->get_inverse(time, value.get(Vector()));
 		else
-			throw Error(_("Inverse manipulation of %s scale values not implemented in core."), value.type_name().c_str());
+			throw Error(_("Inverse manipulation of %s add values not implemented in core."), value.type_name().c_str());
 		Action::Handle action(Action::create("ValueDescSet"));
 		if(!action)
 			throw Error(_("Unable to find action ValueDescSet (bug)"));
@@ -707,7 +714,7 @@ Action::ValueDescSet::prepare()
 		if (value.get_type() == type_angle)
 			new_value = real_value_node->get_inverse(time, value.get(Angle()));
 		else
-			throw Error(_("Inverse manipulation of %s scale values not implemented in core."), value.type_name().c_str());
+			throw Error(_("Inverse manipulation of %s real values not implemented in core."), value.type_name().c_str());
 		Action::Handle action(Action::create("ValueDescSet"));
 		if(!action)
 			throw Error(_("Unable to find action ValueDescSet (bug)"));
@@ -1059,7 +1066,7 @@ Action::ValueDescSet::prepare()
 			// value_node->find throws an exception
 			// when no waypoint is found at given time
 			waypoint=*iter;
-		}catch(Exception::NotFound)
+		}catch(Exception::NotFound&)
 		{
 			waypoint=value_node->new_waypoint_at_time(time);
 			Interpolation inter=value_node->get_interpolation();
@@ -1121,7 +1128,7 @@ Action::ValueDescSet::prepare()
 								 _("Yes"),
 								 synfigapp::UIInterface::RESPONSE_OK ))
 						{
-							throw Error(_("Cancelled by user"));
+							throw Error(Error::TYPE_UNABLE); // Issue  #693
 						}
 					}
 
